@@ -29,12 +29,15 @@ def overlap_start_inclusive(acc, cur, components):
 
 
 def overlap_any_inclusive(acc, cur, components):
-    return acc.start <= cur.start <= acc.end + 1 or acc.start <= cur.end + 1 <= acc.end + 1
+    return (
+        acc.start <= cur.start <= acc.end + 1 or acc.start <= cur.end + 1 <= acc.end + 1
+    )
 
 
 def overlap_end_threshold(threshold):
     def partial(acc, cur, components):
         return acc.start <= cur.start <= acc.end + threshold
+
     return partial
 
 
@@ -47,5 +50,9 @@ def overlap_start_threshold(threshold):
 
 def overlap_any_threshold(threshold):
     def partial(acc, cur, components):
-        return acc.start - threshold <= cur.end + 1 <= acc.end + 1 or acc.start <= cur.start <= acc.end + threshold
+        return (
+            acc.start - threshold <= cur.end + 1 <= acc.end + 1
+            or acc.start <= cur.start <= acc.end + threshold
+        )
+
     return partial
